@@ -1,130 +1,130 @@
 pub static ANIMALS: &[&str] = &[
-    "pigeons",
-    "ferrets",
-    "badgers",
-    "sheep",
-    "crocodiles",
-    "bears",
-    "salmons",
-    "mice",
-    "herons",
-    "hares",
-    "canaries",
-    "owls",
-    "robins",
-    "chickens",
-    "moths",
-    "ibexes",
-    "foxes",
-    "cheetas",
-    "swans",
-    "ewes",
-    "clams",
-    "cattle",
-    "donkeys",
-    "gilamonsters",
-    "chameleons",
-    "cats",
-    "rabbits",
-    "horses",
-    "peafowl",
-    "baboons",
-    "hyenas",
-    "elephants",
-    "starlings",
-    "dromedaries",
-    "dragonflies",
-    "hippopotamuses",
-    "pheasants",
-    "bulls",
-    "squirrels",
-    "camels",
-    "gnus",
-    "elks",
-    "crows",
-    "dogs",
-    "jaguars",
-    "snails",
-    "bats",
-    "doves",
-    "flies",
-    "groundhogs",
-    "gazelles",
-    "dingos",
-    "deer",
-    "alligators",
-    "aardvarks",
-    "otters",
-    "frogs",
-    "coyotes",
-    "stoats",
-    "foxes",
-    "parrots",
-    "fishs",
-    "chipmunks",
-    "ducks",
-    "hawks",
-    "chinchillas",
-    "weasels",
-    "deers",
-    "antelopes",
-    "guineapigs",
-    "mussles",
-    "cougars",
-    "moles",
-    "bats",
-    "hogs",
-    "cockles",
-    "horses",
-    "badgers",
-    "spiders",
-    "jackals",
-    "bisons",
-    "gorillas",
-    "iguanas",
-    "oysters",
-    "gerbils",
-    "geese",
-    "ants",
-    "frogs",
-    "apes",
-    "dogs",
-    "snakes",
-    "grizzlybears",
-    "ferrets",
-    "kingfishers",
-    "finchs",
-    "cows",
-    "donkeys",
-    "hedgehogs",
-    "goats",
-    "pigs",
-    "boars",
-    "butterflies",
-    "rats",
-    "chimpanzees",
-    "famousdog",
-    "gregs",
-    "buffaloes",
-    "impalas",
-    "hamsters",
-    "crows",
-    "beavers",
-    "capybaras",
-    "goats",
-    "pikes",
     "rooks",
-    "crabs",
-    "trouts",
-    "bees",
-    "armadillos",
-    "alpacas",
-    "platypuses",
+    "weasels",
+    "peafowl",
+    "reindeers",
+    "ocelots",
+    "dingos",
+    "spiders",
+    "hawks",
+    "flies",
+    "rhinoceross",
     "hedgehogs",
-    "toads",
-    "giraffes",
+    "prairie_dogs",
+    "armadillos",
+    "rats",
+    "goats",
+    "yaks",
+    "gregs",
+    "antelopes",
+    "parrots",
+    "gazelles",
+    "wildcats",
+    "ewes",
+    "oxs",
+    "horses",
+    "bisons",
+    "squirrels",
+    "crocodiles",
+    "platypuss",
+    "cougars",
+    "minks",
+    "trouts",
+    "wolves",
+    "ground_hogs",
+    "mussles",
+    "guinea_pigs",
+    "snails",
+    "salmons",
+    "porpoises",
+    "gnus",
+    "cockles",
+    "elephants",
+    "lions",
+    "mouses",
+    "finchs",
+    "iguanas",
+    "chipmunks",
+    "capybaras",
+    "walruses",
+    "lemurs",
+    "panthers",
+    "hamsters",
+    "crabs",
+    "bats",
+    "silver_foxs",
+    "shrews",
+    "reptiles",
+    "koalas",
+    "crows",
+    "impalas",
+    "raccoons",
+    "deers",
+    "pheasants",
+    "woodchucks",
+    "donkeys",
+    "dromedaries",
+    "coyotes",
+    "dogs",
+    "elks",
+    "snakes",
+    "pigs",
+    "mynah_birds",
+    "monkeys",
+    "baboons",
+    "kangaroos",
+    "ants",
+    "mongooses",
+    "parakeets",
+    "canaries",
+    "aardvarks",
+    "apes",
+    "pumas",
+    "ducks",
+    "jaguars",
+    "foxes",
+    "beavers",
+    "leopards",
+    "oysters",
+    "kingfishers",
+    "lambs",
+    "boars",
+    "chickens",
+    "otters",
+    "lizards",
+    "turtles",
+    "cats",
     "newts",
-    "sparrows",
+    "jackals",
+    "lynxes",
+    "frogs",
+    "whales",
+    "bulls",
+    "chimpanzees",
+    "mustangs",
+    "hyenas",
+    "mules",
+    "butterflies",
+    "robins",
+    "alpacas",
+    "hares",
+    "rabbits",
+    "rams",
+    "owls",
+    "opossums",
+    "warthogs",
+    "chinchillas",
+    "toads",
+    "gila_monsters",
+    "sheeps",
     "lobsters",
-    "gophers",
+    "ferrets",
+    "oryxs",
+    "polar_bears",
+    "herons",
+    "badgers",
+    "seals",
+    "cattle",
+    "pigeons",
+    "hogs",
 ];
